#[non_exhaustive]pub enum NativeFieldCoveragePlane {
InputObservation,
OutputIntent,
}Expand description
The contract plane represented by one strict coverage-ledger row.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InputObservation
A native Libpod inspection observation accepted by the M2 decoder.
OutputIntent
A caller-declared deployment field classified by planning and rendering contracts.