#[non_exhaustive]pub enum HealthCommand {
Shell(PublicHealthCommand),
Exec(PublicHealthArgumentArray),
SensitiveInlineShell(SensitiveInlineHealthCommand),
SensitiveInlineExec(SensitiveInlineHealthArgumentArray),
ExternalShell(SensitiveInputReference),
ExternalExec(SensitiveInputReference),
}Expand description
One declared health command, preserving shell and exec syntax distinctions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Shell(PublicHealthCommand)
A caller-authorized shell command.
Exec(PublicHealthArgumentArray)
A caller-authorized direct executable and argument array.
SensitiveInlineShell(SensitiveInlineHealthCommand)
An inline sensitive shell command, redacted in all debug output.
SensitiveInlineExec(SensitiveInlineHealthArgumentArray)
An inline sensitive direct command, redacted in all debug output.
ExternalShell(SensitiveInputReference)
A caller-owned sensitive shell-command source, redacted in all debug output.
ExternalExec(SensitiveInputReference)
A caller-owned sensitive direct-command source, redacted in all debug output.